PretrainedInitializer
=====================

.. currentmodule:: pykeen.nn.init

.. autoclass:: PretrainedInitializer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~PretrainedInitializer.__call__
      ~PretrainedInitializer.as_embedding

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: as_embedding
